@@ -219,10 +219,9 @@ void cgi_set_cookie(
     zSecure = " secure;";
   }
   if( lifetime>0 ){
-    lifetime += (int)time(0);
     blob_appendf(&extraHeader,
-       "Set-Cookie: %s=%t; Path=%s; expires=%z; HttpOnly;%s Version=1\r\n",
-        zName, zValue, zPath, cgi_rfc822_datestamp(lifetime), zSecure);
+       "Set-Cookie: %s=%t; Path=%s; max-age=%d; HttpOnly;%s Version=1\r\n",
+        zName, zValue, zPath, lifetime, zSecure);
   }else{
     blob_appendf(&extraHeader,
        "Set-Cookie: %s=%t; Path=%s; HttpOnly;%s Version=1\r\n",
@@ -230,58 +229,6 @@ void cgi_set_cookie(
   }
 }
 
-#if 0
-/*
-** Add an ETag header line
-*/
-static char *cgi_add_etag(char *zTxt, int nLen){
-  MD5Context ctx;
-  unsigned char digest[16];
-  int i, j;
-  char zETag[64];
-
-  MD5Init(&ctx);
-  MD5Update(&ctx,zTxt,nLen);
-  MD5Final(digest,&ctx);
-  for(j=i=0; i<16; i++,j+=2){
-    bprintf(&zETag[j],sizeof(zETag)-j,"%02x",(int)digest[i]);
-  }
-  blob_appendf(&extraHeader, "ETag: %s\r\n", zETag);
-  return fossil_strdup(zETag);
-}
-
-/*
-** Do some cache control stuff. First, we generate an ETag and include it in
-** the response headers. Second, we do whatever is necessary to determine if
-** the request was asking about caching and whether we need to send back the
-** response body. If we shouldn't send a body, return non-zero.
-**
-** Currently, we just check the ETag against any If-None-Match header.
-**
-** FIXME: In some cases (attachments, file contents) we could check
-** If-Modified-Since headers and always include Last-Modified in responses.
-*/
-static int check_cache_control(void){
-  /* FIXME: there's some gotchas wth cookies and some headers. */
-  char *zETag = cgi_add_etag(blob_buffer(&cgiContent),blob_size(&cgiContent));
-  char *zMatch = P("HTTP_IF_NONE_MATCH");
-
-  if( zETag!=0 && zMatch!=0 ) {
-    char *zBuf = fossil_strdup(zMatch);
-    if( zBuf!=0 ){
-      char *zTok = 0;
-      char *zPos;
-      for( zTok = strtok_r(zBuf, ",\"",&zPos);
-           zTok && fossil_stricmp(zTok,zETag);
-           zTok =  strtok_r(0, ",\"",&zPos)){}
-      fossil_free(zBuf);
-      if(zTok) return 1;
-    }
-  }
-
-  return 0;
-}
-#endif
 
 /*
 ** Return true if the response should be sent with Content-Encoding: gzip.
@@ -303,17 +250,6 @@ void cgi_reply(void){
     zReplyStatus = "OK";
   }
 
-#if 0
-  if( iReplyStatus==200 && check_cache_control() ) {
-    /* change the status to "unchanged" and we can skip sending the
-    ** actual response body. Obviously we only do this when we _have_ a
-    ** body (code 200).
-    */
-    iReplyStatus = 304;
-    zReplyStatus = "Not Modified";
-  }
-#endif
-
   if( g.fullHttpReply ){
     fprintf(g.httpOut, "HTTP/1.0 %d %s\r\n", iReplyStatus, zReplyStatus);
     fprintf(g.httpOut, "Date: %s\r\n", cgi_rfc822_datestamp(time(0)));
@@ -322,6 +258,20 @@ void cgi_reply(void){
   }else{
     fprintf(g.httpOut, "Status: %d %s\r\n", iReplyStatus, zReplyStatus);
   }
+  if( g.isConst ){
+    /* isConst means that the reply is guaranteed to be invariant, even
+    ** after configuration changes and/or Fossil binary recompiles. */
+    fprintf(g.httpOut, "Cache-Control: max-age=31536000\r\n");
+  }else if( etag_tag()!=0 ){
+    fprintf(g.httpOut, "ETag: %s\r\n", etag_tag());
+    fprintf(g.httpOut, "Cache-Control: max-age=%d\r\n", etag_maxage());
+  }else{
+    fprintf(g.httpOut, "Cache-control: no-cache\r\n");
+  }
+  if( etag_mtime()>0 ){
+    fprintf(g.httpOut, "Last-Modified: %s\r\n",
+            cgi_rfc822_datestamp(etag_mtime()));
+  }
 
   if( blob_size(&extraHeader)>0 ){
     fprintf(g.httpOut, "%s", blob_buffer(&extraHeader));
@@ -345,20 +295,6 @@ void cgi_reply(void){
   ** a CGI script.
   */
 
-  if( g.isConst ){
-    /* constant means that the input URL will _never_ generate anything
-    ** else. In the case of attachments, the contents won't change because
-    ** an attempt to change them generates a new attachment number. In the
-    ** case of most /getfile calls for specific versions, the only way the
-    ** content changes is if someone breaks the SCM. And if that happens, a
-    ** stale cache is the least of the problem. So we provide an Expires
-    ** header set to a reasonable period (default: one week).
-    */
-    fprintf(g.httpOut, "Cache-control: max-age=28800\r\n");
-  }else{
-    fprintf(g.httpOut, "Cache-control: no-cache\r\n");
-  }
-
   /* Content intended for logged in users should only be cached in
   ** the browser, not some shared location.
   */
@@ -459,6 +395,29 @@ const char *cgi_referer(const char *zDefault){
   return zRef;
 }
 
+/*
+** Return true if the current request appears to be safe from a
+** Cross-Site Request Forgery (CSRF) attack.  Conditions that must
+** be met:
+**
+**    *   The HTTP_REFERER must have the same origin
+**    *   The REQUEST_METHOD must be POST - or requirePost==0
+*/
+int cgi_csrf_safe(int requirePost){
+  const char *zRef = P("HTTP_REFERER");
+  int nBase;
+  if( zRef==0 ) return 0;
+  if( requirePost ){
+    const char *zMethod = P("REQUEST_METHOD");
+    if( zMethod==0 ) return 0;
+    if( strcmp(zMethod,"POST")!=0 ) return 0;
+  }
+  nBase = (int)strlen(g.zBaseURL);
+  if( strncmp(g.zBaseURL,zRef,nBase)!=0 ) return 0;
+  if( zRef[nBase]!=0 && zRef[nBase]!='/' ) return 0;
+  return 1;
+}
+
 /*
 ** Information about all query parameters and cookies are stored
 ** in these variables.
@@ -599,6 +558,11 @@ void cgi_setenv(const char *zName, const char *zValue){
 **         override the value of an environment variable since
 **         environment variables always have uppercase names.
 **
+** 2018-03-29:  Also ignore the entry if NAME that contains any characters
+** other than [a-zA-Z0-9_].  There are no known exploits involving unusual
+** names that contain characters outside that set, but it never hurts to
+** be extra cautious when sanitizing inputs.
+**
 ** Parameters are separated by the "terminator" character.  Whitespace
 ** before the NAME is ignored.
 **
@@ -628,7 +592,7 @@ static void add_param_list(char *z, int terminator){
       if( *z ){ *z++ = 0; }
       zValue = "";
     }
-    if( fossil_islower(zName[0]) ){
+    if( fossil_islower(zName[0]) && fossil_no_strange_characters(zName+1) ){
       cgi_set_parameter_nocopy(zName, zValue, isQP);
     }
 #ifdef FOSSIL_ENABLE_JSON
@@ -1956,53 +1920,40 @@ char *cgi_rfc822_datestamp(time_t now){
 ** most popular one (the one generated by cgi_rfc822_datestamp(), actually).
 */
 time_t cgi_rfc822_parsedate(const char *zDate){
-  struct tm t;
-  char zIgnore[16];
-  char zMonth[16];
-
-  memset(&t, 0, sizeof(t));
-  if( 7==sscanf(zDate, "%12[A-Za-z,] %d %12[A-Za-z] %d %d:%d:%d", zIgnore,
-                       &t.tm_mday, zMonth, &t.tm_year, &t.tm_hour, &t.tm_min,
-                       &t.tm_sec)){
-
-    if( t.tm_year > 1900 ) t.tm_year -= 1900;
-    for(t.tm_mon=0; azMonths[t.tm_mon]; t.tm_mon++){
-      if( !fossil_strnicmp( azMonths[t.tm_mon], zMonth, 3 )){
-        return mkgmtime(&t);
+  int mday, mon, year, yday, hour, min, sec;
+  char zIgnore[4];
+  char zMonth[4];
+  static const char *const azMonths[] =
+    {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
+     "Jul", "Aug", "Sep", "Oct", "Nov", "Dec", 0};
+  if( 7==sscanf(zDate, "%3[A-Za-z], %d %3[A-Za-z] %d %d:%d:%d", zIgnore,
+                       &mday, zMonth, &year, &hour, &min, &sec)){
+    if( year > 1900 ) year -= 1900;
+    for(mon=0; azMonths[mon]; mon++){
+      if( !strncmp( azMonths[mon], zMonth, 3 )){
+        int nDay;
+        int isLeapYr;
+        static int priorDays[] =
+         {  0, 31, 59, 90,120,151,181,212,243,273,304,334 };
+        if( mon<0 ){
+          int nYear = (11 - mon)/12;
+          year -= nYear;
+          mon += nYear*12;
+        }else if( mon>11 ){
+          year += mon/12;
+          mon %= 12;
+        }
+        isLeapYr = year%4==0 && (year%100!=0 || (year+300)%400==0);
+        yday = priorDays[mon] + mday - 1;
+        if( isLeapYr && mon>1 ) yday++;
+        nDay = (year-70)*365 + (year-69)/4 - year/100 + (year+300)/400 + yday;
+        return ((time_t)(nDay*24 + hour)*60 + min)*60 + sec;
       }
     }
   }
-
   return 0;
 }
 
-/*
-** Convert a struct tm* that represents a moment in UTC into the number
-** of seconds in 1970, UTC.
-*/
-time_t mkgmtime(struct tm *p){
-  time_t t;
-  int nDay;
-  int isLeapYr;
-  /* Days in each month:       31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 */
-  static int priorDays[]   = {  0, 31, 59, 90,120,151,181,212,243,273,304,334 };
-  if( p->tm_mon<0 ){
-    int nYear = (11 - p->tm_mon)/12;
-    p->tm_year -= nYear;
-    p->tm_mon += nYear*12;
-  }else if( p->tm_mon>11 ){
-    p->tm_year += p->tm_mon/12;
-    p->tm_mon %= 12;
-  }
-  isLeapYr = p->tm_year%4==0 && (p->tm_year%100!=0 || (p->tm_year+300)%400==0);
-  p->tm_yday = priorDays[p->tm_mon] + p->tm_mday - 1;
-  if( isLeapYr && p->tm_mon>1 ) p->tm_yday++;
-  nDay = (p->tm_year-70)*365 + (p->tm_year-69)/4 -p->tm_year/100 +
-         (p->tm_year+300)/400 + p->tm_yday;
-  t = ((nDay*24 + p->tm_hour)*60 + p->tm_min)*60 + p->tm_sec;
-  return t;
-}
-
 /*
 ** Check the objectTime against the If-Modified-Since request header. If the
 ** object time isn't any newer than the header, we immediately send back
