@@ -51,16 +51,6 @@
 #  include "json_detail.h"
 #endif
 
-/*
-** Size of a UUID in characters.   A UUID is a randomly generated
-** lower-case hexadecimal number used to identify tickets.
-**
-** In Fossil 1.x, UUID also referred to a SHA1 artifact hash.  But that
-** usage is now obsolete.  The term UUID should now mean only a very large
-** random number used as a unique identifier for tickets or other objects.
-*/
-#define UUID_SIZE 40
-
 /*
 ** Maximum number of auxiliary parameters on reports
 */
@@ -517,6 +507,10 @@ static void fossil_sqlite_log(void *notUsed, int iCode, const char *zErrmsg){
   /* Disable the file alias warning on apple products because Time Machine
   ** creates lots of aliases and the warning alarms people. */
   if( iCode==SQLITE_WARNING ) return;
+#endif
+#ifndef FOSSIL_DEBUG
+  /* Disable the automatic index warning except in FOSSIL_DEBUG builds. */
+  if( iCode==SQLITE_WARNING_AUTOINDEX ) return;
 #endif
   if( iCode==SQLITE_SCHEMA ) return;
   if( g.dbIgnoreErrors ) return;
@@ -932,12 +926,16 @@ static void get_version_blob(
   const char *zRc;
 #endif
   Stmt q;
+  size_t pageSize = 0;
   blob_zero(pOut);
   blob_appendf(pOut, "This is fossil version %s\n", get_version());
   if( !bVerbose ) return;
   blob_appendf(pOut, "Compiled on %s %s using %s (%d-bit)\n",
                __DATE__, __TIME__, COMPILER_NAME, sizeof(void*)*8);
   blob_appendf(pOut, "Schema version %s\n", AUX_SCHEMA_MAX);
+  fossil_get_page_size(&pageSize);
+  blob_appendf(pOut, "Detected memory page size is %lu bytes\n",
+               (unsigned long)pageSize);
 #if defined(FOSSIL_ENABLE_MINIZ)
   blob_appendf(pOut, "miniz %s, loaded %s\n", MZ_VERSION, mz_version());
 #else
@@ -1004,6 +1002,9 @@ static void get_version_blob(
 #if defined(HAVE_PLEDGE)
   blob_append(pOut, "HAVE_PLEDGE\n", -1);
 #endif
+#if defined(USE_MMAN_H)
+  blob_append(pOut, "USE_MMAN_H\n", -1);
+#endif
 #if defined(USE_SEE)
   blob_append(pOut, "USE_SEE\n", -1);
 #endif
@@ -1286,35 +1287,63 @@ static int repo_list_page(void){
   n = db_int(0, "SELECT count(*) FROM sfile");
   if( n>0 ){
     Stmt q;
-    @ <h1>Available Repositories:</h1>
-    @ <ol>
+    sqlite3_int64 iNow, iMTime;
+    @ <h1 align="center">Fossil Repositories</h1>
+    @ <table border="0" class="sortable" data-init-sort="1" \
+    @ data-column-types="tnk"><thead>
+    @ <tr><th>Filename<th width="20"><th>Last Modified</tr>
+    @ </thead><tbody>
     db_prepare(&q, "SELECT pathname"
                    " FROM sfile ORDER BY pathname COLLATE nocase;");
+    iNow = db_int64(0, "SELECT strftime('%%s','now')");
     while( db_step(&q)==SQLITE_ROW ){
       const char *zName = db_column_text(&q, 0);
       int nName = (int)strlen(zName);
       char *zUrl;
+      char *zAge;
+      char *zFull;
       if( nName<7 ) continue;
       zUrl = sqlite3_mprintf("%.*s", nName-7, zName);
+      if( zName[0]=='/'
+#ifdef _WIN32
+          || sqlite3_strglob("[a-zA-Z]:/*", zName)==0
+#endif
+      ){
+        zFull = mprintf("%s", zName);
+      }else if ( allRepo ){
+        zFull = mprintf("/%s", zName);
+      }else{
+        zFull = mprintf("%s/%s", g.zRepositoryName, zName);
+      }
+      iMTime = file_mtime(zFull, ExtFILE);
+      fossil_free(zFull);
+      if( iMTime<=0 ){
+        zAge = mprintf("...");
+      }else{
+        zAge = human_readable_age((iNow - iMTime)/86400.0);
+      }
       if( sqlite3_strglob("*.fossil", zName)!=0 ){
         /* The "fossil server DIRECTORY" and "fossil ui DIRECTORY" commands
         ** do not work for repositories whose names do not end in ".fossil".
         ** So do not hyperlink those cases. */
-        @ <li>%h(zName)</li>
+        @ <tr><td>%h(zName)
       } else if( sqlite3_strglob("*/.*", zName)==0 ){
         /* Do not show hidden repos */
-        @ <li>%h(zName) (hidden)</li>
+        @ <tr><td>%h(zName) (hidden)
       } else if( allRepo && sqlite3_strglob("[a-zA-Z]:/?*", zName)!=0 ){
-        @ <li><a href="%R/%T(zUrl)/home" target="_blank">/%h(zName)</a></li>
+        @ <tr><td><a href="%R/%T(zUrl)/home" target="_blank">/%h(zName)</a>
       }else{
-        @ <li><a href="%R/%T(zUrl)/home" target="_blank">%h(zName)</a></li>
+        @ <tr><td><a href="%R/%T(zUrl)/home" target="_blank">%h(zName)</a>
       }
+      @ <td></td><td data-sortkey='%010llx(iNow - iMTime)'>%h(zAge)</tr>
+      fossil_free(zAge);
       sqlite3_free(zUrl);
     }
-    @ </ol>
+    @ </tbody></table>
   }else{
     @ <h1>No Repositories Found</h1>
   }
+  @ <script>%s(builtin_text("sorttable.js"))</script>
   @ </body>
   @ </html>
   cgi_reply();
@@ -1323,6 +1352,24 @@ static int repo_list_page(void){
   return n;
 }
 
+/*
+** COMMAND: test-list-page
+**
+** Usage: %fossil test-list-page DIRECTORY
+**
+** Show all repositories underneath DIRECTORY.  Or if DIRECTORY is "/"
+** show all repositories in the ~/.fossil file.
+*/
+void test_list_page(void){
+  if( g.argc<3 ){
+    g.zRepositoryName = "/";
+  }else{
+    g.zRepositoryName = g.argv[2];
+  }
+  g.httpOut = stdout;
+  repo_list_page();
+}
+
 /*
 ** Preconditions:
 **
@@ -2462,9 +2509,6 @@ void cmd_webserver(void){
   g.sslNotAvailable = find_option("nossl", 0, 0)!=0;
   if( find_option("https",0,0)!=0 ){
     cgi_replace_parameter("HTTPS","on");
-  }else{
-    /* without --https, defaults to not available. */
-    g.sslNotAvailable = 1;
   }
   if( find_option("localhost", 0, 0)!=0 ){
     flags |= HTTP_SERVER_LOCALHOST;
